model world_force_pendulum_2
  Modelica.Mechanics.MultiBody.Parts.BodyBox cart(density(displayUnit = "kg/m3") = 1000, height = 0.1, r = {0.1, 0, 0}, width = 0.1, color = Modelica.Mechanics.MultiBody.Types.Defaults.JointColor, animation = true) annotation(Placement(visible = true, transformation(origin = {8.4, -28.4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.MultiBody.Parts.BodyCylinder pendulumCylinder(r = {0, 1.0, 0}, diameter = 0.0063, density(displayUnit = "kg/m3") = 3200) annotation(Placement(visible = true, transformation(origin = {98.4, -28.4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.MultiBody.Joints.Revolute pendulumJoint(useAxisFlange = true, cylinderDiameter = 2 * 0.01, a.start = 0., phi.fixed = true, w.fixed = true, a.fixed = true, phi.displayUnit = "rad", phi.start = ICphi, w.start = IComega) annotation(Placement(visible = true, transformation(origin = {68.4, -28.4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.MultiBody.Parts.FixedTranslation toMidCart(r = {-cart.r[1] / 2, cart.height / 2, 0}) annotation(Placement(visible = true, transformation(origin = {38.4, -28.4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.MultiBody.Joints.Prismatic sliderConstraint(stateSelect = StateSelect.prefer, useAxisFlange = true, animation = false, s(fixed = true, start = ICx), a.start = 0., v.fixed = true, a.fixed = true, v.start = ICv) annotation(Placement(visible = true, transformation(origin = {-51.6, -28.4}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Sensors.AngleSensor angleSensor annotation(Placement(visible = true, transformation(origin = {98.4, 1.6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Translational.Sensors.PositionSensor positionSensor annotation(Placement(visible = true, transformation(origin = {-13.145, -67.25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealOutput x annotation(Placement(visible = true, transformation(origin = {30, -67.25}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {118, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealOutput phi annotation(Placement(visible = true, transformation(origin = {128.4, 1.6}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {118, 62}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  inner Modelica.Mechanics.MultiBody.World world(animateWorld = false, animateGravity = false) annotation(Placement(visible = true, transformation(origin = {-105, -28.4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.MultiBody.Parts.FixedTranslation center(r = {-0.1 / 2, 0.1 / 2, 0}, animation = false) annotation(Placement(visible = true, transformation(origin = {-21.6, -28.4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.MultiBody.Forces.WorldForce force(resolveInFrame = Modelica.Mechanics.MultiBody.Types.ResolveInFrameB.frame_b) annotation(Placement(visible = true, transformation(origin = {-75, 5}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  parameter Real ICx = 0.0;
  parameter Real ICv = 0.0;
  parameter Real ICphi = 0.0;
  parameter Real IComega = 0.0;
  Modelica.Blocks.Interfaces.RealInput u[3] annotation(Placement(visible = true, transformation(origin = {-130, 15}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-79.099, 9.524}, extent = {{-20, -20}, {20, 20}}, rotation = 0)), Dialog(group = "Variables"));
equation
  connect(world.frame_b, sliderConstraint.frame_a) annotation(Line(visible = true, origin = {-78.3, -28.4}, points = {{-16.7, 0}, {16.7, 0}}, color = {95, 95, 95}));
  connect(center.frame_b, cart.frame_a) annotation(Line(visible = true, origin = {-6.6, -28.4}, points = {{-5, 0}, {5, 0}}, color = {95, 95, 95}));
  connect(sliderConstraint.frame_b, center.frame_a) annotation(Line(visible = true, origin = {-36.6, -28.4}, points = {{-5, 0}, {5, 0}}, color = {95, 95, 95}));
  connect(cart.frame_b, toMidCart.frame_a) annotation(Line(visible = true, origin = {23.4, -28.4}, points = {{-5, 0}, {5, 0}}, color = {95, 95, 95}));
  connect(toMidCart.frame_b, pendulumJoint.frame_a) annotation(Line(visible = true, origin = {53.4, -28.4}, points = {{-5, 0}, {5, 0}}, color = {95, 95, 95}));
  connect(pendulumJoint.frame_b, pendulumCylinder.frame_a) annotation(Line(visible = true, origin = {83.4, -28.4}, points = {{-5, 0}, {5, 0}}, color = {95, 95, 95}));
  connect(angleSensor.phi, phi) annotation(Line(visible = true, origin = {118.9, 1.6}, points = {{-9.5, 0}, {9.5, 0}}, color = {1, 37, 163}));
  connect(positionSensor.s, x) annotation(Line(visible = true, origin = {13.927, -67.25}, points = {{-16.073, 0}, {16.073, 0}}, color = {1, 37, 163}));
  connect(angleSensor.flange, pendulumJoint.axis) annotation(Line(visible = true, origin = {75.067, -5.067}, points = {{13.333, 6.667}, {-6.667, 6.667}, {-6.667, -13.333}}, color = {64, 64, 64}));
  connect(positionSensor.flange, sliderConstraint.axis) annotation(Line(visible = true, origin = {-35.874, -50.825}, points = {{12.728, -16.425}, {-2.501, -16.425}, {-2.501, 16.425}, {-7.726, 16.425}}, color = {0, 127, 0}));
  connect(force.frame_b, sliderConstraint.frame_b) annotation(Line(visible = true, origin = {-45.837, -11.7}, points = {{-19.163, 16.7}, {7.462, 16.7}, {7.462, -16.7}, {4.237, -16.7}}, color = {95, 95, 95}));
  connect(u, force.force) annotation(Line(visible = true, origin = {-99.25, 10}, points = {{-30.75, 5}, {9.25, 5}, {9.25, -5}, {12.25, -5}}, color = {1, 37, 163}));
  annotation(Diagram(coordinateSystem(extent = {{-148.5, -105}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
end world_force_pendulum_2;
